Class: Herb::Embedded::EngineAdapter::Binary
- Inherits:
-
Struct
- Object
- Struct
- Herb::Embedded::EngineAdapter::Binary
- Defined in:
- lib/herb/embedded/engine_adapter.rb
Overview
Marks a Ruby string as binary data that must cross the engine boundary as a byte array (e.g. a Uint8Array), not a JS string, since arbitrary bytes are not valid UTF-8.
Instance Attribute Summary collapse
-
#raw ⇒ Object
Returns the value of attribute raw.
Instance Attribute Details
#raw ⇒ Object
Returns the value of attribute raw
12 13 14 |
# File 'lib/herb/embedded/engine_adapter.rb', line 12 def raw @raw end |